aboutsummaryrefslogtreecommitdiff
path: root/tagging/settings.py
diff options
context:
space:
mode:
Diffstat (limited to 'tagging/settings.py')
-rw-r--r--tagging/settings.py26
1 files changed, 13 insertions, 13 deletions
diff --git a/tagging/settings.py b/tagging/settings.py
index 18321bd..78da3af 100644
--- a/tagging/settings.py
+++ b/tagging/settings.py
@@ -1,13 +1,13 @@
-"""
-Convenience module for access of custom tagging application settings,
-which enforces default settings when the main settings module which has
-been configured does not contain the appropriate settings.
-"""
-from django.conf import settings
-
-# Whether to force all tags to lowercase before they are saved to the
-# database. Default is False.
-try:
- FORCE_LOWERCASE_TAGS = settings.FORCE_LOWERCASE_TAGS
-except AttributeError:
- FORCE_LOWERCASE_TAGS = False
+"""
+Convenience module for access of custom tagging application settings,
+which enforces default settings when the main settings module does not
+contain the appropriate settings.
+"""
+from django.conf import settings
+
+# The maximum length of a tag's name.
+MAX_TAG_LENGTH = getattr(settings, 'MAX_TAG_LENGTH', 50)
+
+# Whether to force all tags to lowercase before they are saved to the
+# database.
+FORCE_LOWERCASE_TAGS = getattr(settings, 'FORCE_LOWERCASE_TAGS', False)